Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(589)

Unified Diff: test/mjsunit/regress/regress-function-constructor-receiver.js

Issue 1415683007: Reland "[es6] Fix Function and GeneratorFunction built-ins subclassing." (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@fix-subclass
Patch Set: Improved test Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/mjsunit/es6/classes-subclass-builtins.js ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/mjsunit/regress/regress-function-constructor-receiver.js
diff --git a/test/mjsunit/regress/regress-function-constructor-receiver.js b/test/mjsunit/regress/regress-function-constructor-receiver.js
index f345435ade0d72063307bf49267e9f11513ce42d..5d713803bef1ff93e99f20fd0510933df43a826f 100644
--- a/test/mjsunit/regress/regress-function-constructor-receiver.js
+++ b/test/mjsunit/regress/regress-function-constructor-receiver.js
@@ -10,8 +10,8 @@ try {
new Function({toString:0,valueOf:0});
} catch (e) {
threw = true;
- // Ensure that the receiver during "new Function" is the global proxy.
- assertEquals(this, e.stack[0].getThis());
+ // Ensure that the receiver during "new Function" is the undefined value.
+ assertEquals(undefined, e.stack[0].getThis());
}
assertTrue(threw);
« no previous file with comments | « test/mjsunit/es6/classes-subclass-builtins.js ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698